package com.jpsoft.picc.modules.business.controller;

import com.github.pagehelper.Page;
import com.jpsoft.picc.modules.business.entity.StudentApplication;
import com.jpsoft.picc.modules.business.service.StudentApplicationService;
import com.jpsoft.picc.modules.common.dto.Sort;
import com.jpsoft.picc.modules.common.dto.MessageResult;
import com.jpsoft.picc.modules.common.utils.PojoUtils;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.apache.commons.lang3.StringUtils;
import org.slf4j.Logger;
import org.slf4j.LoggerFactory;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import javax.servlet.http.HttpServletRequest;
import java.text.SimpleDateFormat;
import java.util.*;

@RestController
@RequestMapping("/business/studentApplication")
@Api(description = "studentApplication")
public class StudentApplicationController {
    private Logger logger = LoggerFactory.getLogger(getClass());

    @Autowired
    private StudentApplicationService studentApplicationService;

    @ApiOperation(value="创建空记录")
    @GetMapping("create")
    public MessageResult<StudentApplication> create(){
        MessageResult<StudentApplication> msgResult = new MessageResult<>();

        StudentApplication studentApplication = new StudentApplication();

        msgResult.setData(studentApplication);
        msgResult.setResult(true);

        return msgResult;
    }
    
    @ApiOperation(value="添加信息")
    @PostMapping("add")
    public MessageResult<StudentApplication> add(@RequestBody StudentApplication studentApplication,@RequestAttribute String subject){
        MessageResult<StudentApplication> msgResult = new MessageResult<>();

        try {
            studentApplication.setId(UUID.randomUUID().toString());
            studentApplication.setDelFlag(false);
            studentApplication.setCreateBy(subject);
            studentApplication.setCreateTime(new Date());
            
            int affectCount = studentApplicationService.insert(studentApplication);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(studentApplication);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库添加失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="获取信息")
    @GetMapping("edit/{id}")
    public MessageResult<StudentApplication> edit(@PathVariable("id") String id){
        MessageResult<StudentApplication> msgResult = new MessageResult<>();

        try {
            StudentApplication studentApplication = studentApplicationService.get(id);

            if (studentApplication != null) {
                msgResult.setResult(true);
                msgResult.setData(studentApplication);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库不存在该记录!");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="更新用户")
    @PostMapping("update")
    public MessageResult<StudentApplication> update(@RequestBody StudentApplication studentApplication,@RequestAttribute String subject){
        MessageResult<StudentApplication> msgResult = new MessageResult<>();

        try {
            studentApplication.setUpdateBy(subject);
            studentApplication.setUpdateTime(new Date());
            
            int affectCount = studentApplicationService.update(studentApplication);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(studentApplication);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("数据库更新失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

	@ApiOperation(value="删除")
    @PostMapping("delete/{id}")
    public MessageResult<Integer> delete(@PathVariable("id") String id,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            StudentApplication studentApplication = studentApplicationService.get(id);
            studentApplication.setDelFlag(true);
            studentApplication.setUpdateBy(subject);
            studentApplication.setUpdateTime(new Date());

            int affectCount = studentApplicationService.update(studentApplication);

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }


    @ApiOperation(value="批量删除")
    @PostMapping("batchDelete")
    public MessageResult<Integer> batchDelete(@RequestBody List<String> idList,@RequestAttribute String subject){
        MessageResult<Integer> msgResult = new MessageResult<>();

        try {
            int affectCount = 0;

            for (String id : idList) {
                StudentApplication studentApplication = studentApplicationService.get(id);
                studentApplication.setDelFlag(true);
                studentApplication.setUpdateBy(subject);
                studentApplication.setUpdateTime(new Date());

                affectCount += studentApplicationService.update(studentApplication);
            }

            if (affectCount > 0) {
                msgResult.setResult(true);
                msgResult.setData(affectCount);
            } else {
                msgResult.setResult(false);
                msgResult.setMessage("删除失败");
            }
        }
        catch(Exception ex){
            logger.error(ex.getMessage(),ex);

            msgResult.setResult(false);
            msgResult.setMessage(ex.getMessage());
        }

        return msgResult;
    }

    @ApiOperation(value="列表")
    @RequestMapping(value = "pageList",method = RequestMethod.POST)
    public MessageResult<Map> pageList(
            String id,
            @RequestParam(value="pageIndex",defaultValue="1") int pageIndex,
            @RequestParam(value="pageSize",defaultValue="20") int pageSize,
            @RequestAttribute String subject){

        //当前用户ID
        System.out.println(subject);

        MessageResult<Map> msgResult = new MessageResult<>();

        Map<String,Object> searchParams = new HashMap<>();

        List<Sort> sortList = new ArrayList<>();
        sortList.add(new Sort("id_","asc"));

        if (StringUtils.isNotEmpty(id)) {
            searchParams.put("id","%" + id + "%");
        }

        Page<StudentApplication> page = studentApplicationService.pageSearch(searchParams,pageIndex,pageSize,true,sortList);

        msgResult.setResult(true);
        msgResult.setData(PojoUtils.pageWrapper(page));

        return msgResult;
    }
}
